# HG changeset patch
# Node ID 5fd6c8f35613
# Parent  867b39d2bc08
diff --git a/ChangeLog b/ChangeLog
--- a/ChangeLog
+++ b/ChangeLog
@@ -80,7 +80,7 @@ version 3.0.0 (??/??/????):
 	* The Offline Message Emulation plugin now adds a note that the message
 	  was an offline message. (Flavius Anton) (#2497)
 	* IPC test plugins have been removed, since the new plugin API does not
-	  provide a seperate IPC API.
+	  provide a separate IPC API.
 
 	Protocols:
 	* A single jabber plugin provides XMPP, GTalk and Facebook protocols.
@@ -147,7 +147,7 @@ version 2.14.0 (10/06/2020):
 version 2.13.0 (03/08/2018):
 	libpurple:
 	* Unified string comparison. (PR #186) (Arkadiy Illarionov)
-	* Properlly shell escape URI's when opening them. (PR #271 Daniel Kamil Kozar)
+	* Properly shell escape URI's when opening them. (PR #271 Daniel Kamil Kozar)
 	* Fix a one byte buffer overread in function purple_markup_linkify
 	* Fix an issue were utf8 was incorrectly truncated which could lead to
 	  crashes as we were potentially feeding garbage into glib/gtk.
@@ -1014,7 +1014,7 @@ version 2.7.11 (03/10/2011):
 	  to 32 packets.
 
 	XMPP:
-	* Fix building on platforms with an older glib (inadvertantly broken in
+	* Fix building on platforms with an older glib (inadvertently broken in
 	  2.7.10).  (#13329)
 	* Don't treat the on-join status storms as 'new arrivals'.  (Thijs
 	  Alkemade) (#a14527)
@@ -1222,7 +1222,7 @@ version 2.7.5 (10/31/2010):
 	  Information dialog.
 
 	AIM and/or ICQ:
-	* Display the "Authorize buddy?" minidialog when the requestor has an
+	* Display the "Authorize buddy?" minidialog when the requester has an
 	  empty nickname. (#12810)
 	* New ICQ accounts default to proper ICQ servers.  Old accounts using one
 	  of the old default servers will be silently migrated to use the proper
@@ -1708,7 +1708,7 @@ version 2.6.6 (02/18/2010):
 	* Fix CVE-2010-0423, a denial of service attack due to the parsing
 	  of large numbers of smileys.  (Discovered by Antti Hayrynen)
 	* Correctly size conversation and status box entries when the
-	  interior-focus style property is diabled. (Gabriel Schulhof)
+	  interior-focus style property is disabled. (Gabriel Schulhof)
 	* Correctly handle a multiline text field being required in a
 	  request form.  (Thanks to Florian Zeitz for finding this problem)
 	* Search friends by email-addresses in the buddy list. (Luoh Ren-Shan)
@@ -2179,7 +2179,7 @@ version 2.5.8 (06/27/2009):
 	  the pain of transition to the new login method.
 
 	XMPP:
-	* Fix an incompatibility betweeen Prosody and libpurple clients.
+	* Fix an incompatibility between Prosody and libpurple clients.
 
 version 2.5.7 (06/20/2009):
 	* Yahoo Protocol 16 support, including new HTTPS login method; this should
@@ -2467,7 +2467,7 @@ version 2.5.2 (10/19/2008):
 	  help with discoverability.  CTRL+S is no longer bound to mute.
 	* Added ability to change the color of visited links (using the theme
 	  control plugin, or setting the color in ~/.gtkrc-2.0)
-	* Fix a crash occuring when a custom smiley is deleted and re-added and
+	* Fix a crash occurring when a custom smiley is deleted and re-added and
 	  used in an open conversation after being re-added.
 
 	Finch:
@@ -2743,7 +2743,7 @@ version 2.4.0 (02/29/2008):
 	  request dialog. M-d will properly delete-forward-word, and M-f has been
 	  fixed to imitate readline's behavior.
 	* New bindings alt+tab and alt+shift+tab to help navigating between the
-	  higlighted windows (details on the man page).
+	  highlighted windows (details on the man page).
 	* Recently signed on (or off) buddies blink in the buddy list.
 	* New action 'Room List' in the action list can be used to get the list of
 	  available chat rooms for an online account.
@@ -3195,7 +3195,7 @@ version 2.0.0 (5/3/2007):
 	* Perl plugin loader has been rewritten (John Kelm, Google Summer
 	  of Code)
 	* New music messaging plugin (Christian Muise, Google Summer of Code)
-	* gaim-remote has been superceded by new DBUS bindings within libpurple
+	* gaim-remote has been superseded by new DBUS bindings within libpurple
 	  (Piotr Zielinski, Google Summer of Code)
 	* The purple-url-handler program has been added to provide a way to
 	  automatically launch IM links via Pidgin or Finch.
@@ -3714,7 +3714,7 @@ version 0.79 (06/24/2004):
 	  the account was modified. Now they're only removed when the protocol
 	  type changes, as it should be.
 	* Zephyr bug fixes and memory leak plugs (Arun A Tharuvai)
-	* Rewrite of MSN buddylist support, which fixed a known syncronization
+	* Rewrite of MSN buddylist support, which fixed a known synchronization
 	  bug and some others (Felipe Contreras)
 
 version 0.78 (05/30/2004):
@@ -4209,7 +4209,7 @@ version 0.60 (04/04/2003):
 
 	IRC:
 	* Added more IRC slash commands -- /W, /VERSION, /MODE, /CTCP stuff,
-	  -- and other cool IRC enhancments. (Thanks, Jonas Birmé)
+	  -- and other cool IRC enhancements. (Thanks, Jonas Birmé)
 	* IRC's /topic with no argument displays the current topic (Thanks,
 	  Mark Doliner)
 	* DCC File Receive support for IRC.
@@ -4245,7 +4245,7 @@ version 0.60 (04/04/2003):
 	* Add / Remove buddy menu item added to the chat users list
 	  (Thanks, Jonas Birmé)
 	* View log button in conversation toolbar (Thanks, Etan Reisner)
-	* Option to log IMs and Chats seperately. (Thanks, Etan
+	* Option to log IMs and Chats separately. (Thanks, Etan
 	  Reisner)
 	* Removed Ctrl-C binding for color
 	* Fix first message in tab not displaying bug (Thanks, Etan Reisner)
@@ -4264,7 +4264,7 @@ version 0.60 (04/04/2003):
 	  Ka-Hing Cheung)
 	* Word-wrapping on mail notification text (Thanks, Andrew Molloy)
 	* Generic File Transfer PRPL interface (Thanks, Christian Hammond)
-	* Better supression of auto-responses (Thanks, Joshua Blanton)
+	* Better suppression of auto-responses (Thanks, Joshua Blanton)
 	* Drag-and-drop tabs in conversations, and multiple windows with tabs
 	  in each (Thanks, Christian Hammond)
 
@@ -4381,7 +4381,7 @@ version 0.59 (06/24/2002):
 	* Perl scripts can play Gaim sounds (thanks Andrew Rodland)
 	* Internal sounds can be played by commands (thanks Lex Spoon)
 	* Auto-login item in applet menu (thanks Chris Boyle)
-	* Fixed MSN "Unkown Error Code", "Already there", and
+	* Fixed MSN "Unknown Error Code", "Already there", and
 	  "Already in opposite list" errors
 	* Changed "Play sound" button to "Mute" button
 	* You can now have "reserved" chars in IM and proxy passwords
@@ -4458,10 +4458,10 @@ version 0.56 (04/11/2002):
 	* Buddylist looks a little better
 	* Fixed MSN privacy settings
 	* Group deletion fix (Thanks Mark Doliner)
-	* Alias/Group syncronization for Jabber (Thanks JSeymour)
+	* Alias/Group synchronization for Jabber (Thanks JSeymour)
 	* Fixed broken signal handling in gdm-started GNOME sessions
 	  (Thanks Jim Seymour, Vann, Robert McQueen)
-	* Oscar group syncronization (Thanks, Mark Doliner)
+	* Oscar group synchronization (Thanks, Mark Doliner)
 	* ICQ Authorization via Oscar (Thanks, Mark Doliner)
 
 version 0.55 (03/29/2002):
@@ -4820,7 +4820,7 @@ version 0.11.0-pre3 (12/15/2000):
 	* Away messages arranged alphabetically (Thanks Justin)
 	* More GUI adjustments
 	* Can optionally run command to play sound files
-	* Icons for ICQ plugin (blatently stolen from GnomeICU)
+	* Icons for ICQ plugin (blatantly stolen from GnomeICU)
 	* Icons for Yahoo plugin (not-so-blatently stolen from GTKYahoo)
 	* Optionally display warning level next to name in buddy list
 	* Optionally ignore fonts on incoming messages
@@ -4862,7 +4862,7 @@ version 0.10.3 (10/09/2000):
 version 0.10.2 (10/07/2000):
 	* A few fixes to the URL parser.
 	* Better placement of smiley dialog
-	* Improved log file readibility
+	* Improved log file readability
 	* Code cleanups (thanks kylev)
 	* Fixed problem when closing away message box (thanks bmiller)
 	* sprintf() problem on some systems
@@ -4993,7 +4993,7 @@ version 0.9.13 (03/27/2000):
 	* GNOME compile error fixed
 	* Away Message Problem Fixed
 	* Fixed URL Right Click Menus
-	* Conversation Loggin now shows Full Date and Time
+	* Conversation Logging now shows Full Date and Time
 	* Internal Change to Buddy List
 
 version 0.9.12 (03/25/2000):
@@ -5071,7 +5071,7 @@ version 0.9.7  (08/08/1999):
 version 0.9.6  (08/01/1999):
 	* Fixed 'log all conversation' segfault
 	* Added NAS support
-	* Removed Xmu dependancies.
+	* Removed Xmu dependencies.
 	* Restructured network code
 	* ESD detection more robust.
 	* Sound fallbacks are MUCH more robust!
diff --git a/ChangeLog.API b/ChangeLog.API
--- a/ChangeLog.API
+++ b/ChangeLog.API
@@ -2021,12 +2021,12 @@ version 2.3.0 (11/24/2007):
 		* purple_network_listen_map_external()
 
 		MSN:
-		* A new independant status type with PURPLE_STATUS_TUNE primitive, and
+		* A new independent status type with PURPLE_STATUS_TUNE primitive, and
 		  PURPLE_TUNE_ARTIST, PURPLE_TUNE_ALBUM and PURPLE_TUNE_TITLE
 		  attributes.
 
 		XMPP:
-		* A new independant status type with PURPLE_STATUS_TUNE primitive, and
+		* A new independent status type with PURPLE_STATUS_TUNE primitive, and
 		  PURPLE_TUNE_{ARTIST, TITLE, ALBUM, GENRE, COMMENT, TRACK, TIME,
 		  YEAR, URL} attributes.
 
@@ -2234,7 +2234,7 @@ version 2.1.0 (7/28/2007):
 			* gnt_tree_set_column_is_right_aligned
 			* gnt_tree_set_search_function, gnt_tree_set_search_column,
 			  gnt_tree_is_searching
-			* 'file-selected' signal is emited for GntFileSel
+			* 'file-selected' signal is emitted for GntFileSel
 			* gnt_style_parse_bool
 			* gnt_util_set_trigger_widget
 
@@ -2290,7 +2290,7 @@ version 2.0.0 (5/3/2007):
 	* gtk_imhtml_toggle_italic(): No longer returns a value
 	* gtk_imhtml_toggle_underline(): No longer returns a value
 	* gtk_imhtml_toggle_strike(): No longer returns a value
-	* gtk_imhtml_scroll_to_end(): Added the smooth paramter
+	* gtk_imhtml_scroll_to_end(): Added the smooth parameter
 	* gaim_log_new(), added conv parameter
 	* gaim_buddy_icon_new(), leaves a reference which the caller owns.  Use
 	  gaim_buddy_icon_unref() immediately if you don't want a reference (the
@@ -2359,9 +2359,10 @@ version 2.0.0 (5/3/2007):
 	  FALSE.  Previously they were set to TRUE or left alone.  Also, you
 	  may now pass NULL if you're not interested in a specific formatting.
 	* Smiley Themes: Backslashes must be backslash-escaped.
-	* Plugins: Depedencies are now honored when unloading plugins.
+	* Plugins: Dependencies are now honored when unloading plugins.
 	* gaim_markup_extract_info_field(): Added format_cb parameter.
-	* gaim_markup_extract_info_field(): Changed GString parameter to a GaimNotifyUserInfo paramter.
+	* gaim_markup_extract_info_field(): Changed GString parameter to a
+	  GaimNotifyUserInfo parameter.
 	* gaim_str_to_time(): Added support for parsing the MM/DD/YYYY format.
 	* gaim_plugin_action_new(): label is now const char *
 	* gaim_plugin_pref_new_with_name(): name is now const char *
@@ -2549,7 +2550,7 @@ version 2.0.0 (5/3/2007):
 	* gaim_util_chrreplace() to replace a given character with a
 	  different character
 	* gaim_gtk_blist_toggle_visibility() to intelligently toggle the
-	  visiblity of the buddy list
+	  visibility of the buddy list
 	* gaim_gtk_blist_visibility_manager_add() to indicate the addition of a
 	  visibility manager - see the docs for more information
 	* gaim_gtk_blist_visibility_manager_remove() to indicate the removal of
@@ -2782,7 +2783,7 @@ version 1.1.0 (12/02/2004):
 		 #ifdef ENABLE_BINRELOC from prefix.h, it won't be
 		 loadable on a copy of Gaim compiled without binreloc
 		 support. In particular, watch out for the autoconf-like
-		 macros, and accidently including them through internal.h,
+		 macros, and accidentally including them through internal.h,
 		 which you probably shouldn't be including anyway.
 
 version 1.0.0 (09/17/2004):
@@ -2923,17 +2924,17 @@ version 0.78 (05/30/2004):
 	* Added: "buddy-idle-updated" signal, for when the idle time changes.
 	* Changed: "received-im-msg" and "received-chat-msg" no longer pass
 			   pointers to who, message and flags, and are now void.
-	* Removed: "drawing-menu" - it was UI sepecific and
+	* Removed: "drawing-menu" - it was UI-specific and
 			   "blist-node-extended-menu" is superior
 
 version 0.77 (04/22/2004):
-	Loader & Protocol Plugins independantly versioned
+	Loader & Protocol Plugins independently versioned
 	Plugin loading now checks versioning on plugins (Standard, Loader &
 	Protocol)
 	new GAIM_{PLUGIN,PRPL,LOADER}_API_VERSION constants
 
 	Plugin API: v3
-	* Added: prefs_info for UI independant plugin prefs
+	* Added: prefs_info for UI independent plugin prefs
 
 	Loader Plugin API: v2
 	* Added: api_version at top of GaimPluginLoaderInfo struct
diff --git a/README b/README
--- a/README
+++ b/README
@@ -94,5 +94,5 @@ You can find more information about Pidg
 Pidgin is supported by DigitalOcean who graciously sponsors all of our
 infrastructure.
 
-[![DigitalOcean referal link](img/DO_Logo_horizontal_blue.png)](https://www.digitalocean.com/?refcode=b69e5dddf595&utm_campaign=Referral_Invite&utm_medium=Referral_Program&utm_source=badge)
+[![DigitalOcean referral link](img/DO_Logo_horizontal_blue.png)](https://www.digitalocean.com/?refcode=b69e5dddf595&utm_campaign=Referral_Invite&utm_medium=Referral_Program&utm_source=badge)
 
diff --git a/libpurple/media.h b/libpurple/media.h
--- a/libpurple/media.h
+++ b/libpurple/media.h
@@ -523,7 +523,7 @@ gboolean purple_media_set_send_rtcp_mux(
  *
  * Gets whether the local user is the conference/session/stream's initiator.
  *
- * Returns: TRUE if the local user is the stream's initator, else FALSE.
+ * Returns: TRUE if the local user is the stream's initiator, else FALSE.
  *
  * Since: 2.6.0
  */
diff --git a/libpurple/protocols/gg/roster.c b/libpurple/protocols/gg/roster.c
--- a/libpurple/protocols/gg/roster.c
+++ b/libpurple/protocols/gg/roster.c
@@ -1039,7 +1039,7 @@ static void ggp_roster_reply_ack(PurpleC
 	}
 
 	/* we need to remove "synchronized" flag for all contacts, that have
-	 * beed modified between roster update start and now
+	 * been modified between roster update start and now
 	 */
 	updates_it = g_list_first(rdata->pending_updates);
 	while (updates_it) {
diff --git a/libpurple/purplecredentialprovider.c b/libpurple/purplecredentialprovider.c
--- a/libpurple/purplecredentialprovider.c
+++ b/libpurple/purplecredentialprovider.c
@@ -242,7 +242,7 @@ purple_credential_provider_class_init(Pu
 	 * Since: 3.0.0
 	 */
 	properties[PROP_SETTINGS] = g_param_spec_object(
-		"settings", "setings",
+		"settings", "settings",
 		"The GSettings for the provider",
 		G_TYPE_SETTINGS,
 		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
diff --git a/libpurple/purplenotificationmanager.c b/libpurple/purplenotificationmanager.c
--- a/libpurple/purplenotificationmanager.c
+++ b/libpurple/purplenotificationmanager.c
@@ -383,7 +383,7 @@ purple_notification_manager_remove(Purpl
 		g_object_ref(notification);
 
 		g_ptr_array_remove_index(manager->notifications, index);
-		/* Remove the notify signal handler for the read state incase someone
+		/* Remove the notify signal handler for the read state in case someone
 		 * else added a reference to the notification which would then mess
 		 * with our unread count accounting.
 		 */
diff --git a/libpurple/tests/test_contact_manager.c b/libpurple/tests/test_contact_manager.c
--- a/libpurple/tests/test_contact_manager.c
+++ b/libpurple/tests/test_contact_manager.c
@@ -115,7 +115,7 @@ test_purple_contact_manager_double_add(v
 		purple_contact_manager_add(manager, contact);
 
 		/* This will never get called as the double add outputs a g_warning()
-		 * that causes the test to fail. This is left to avoid a false postive
+		 * that causes the test to fail. This is left to avoid a false positive
 		 * in static analysis.
 		 */
 		g_clear_object(&account);
diff --git a/libpurple/tests/test_notification_manager.c b/libpurple/tests/test_notification_manager.c
--- a/libpurple/tests/test_notification_manager.c
+++ b/libpurple/tests/test_notification_manager.c
@@ -121,7 +121,7 @@ test_purple_notification_manager_double_
 		purple_notification_manager_add(manager, notification);
 
 		/* This will never get called as the double add outputs a g_warning()
-		 * that causes the test to fail. This is left to avoid a false postive
+		 * that causes the test to fail. This is left to avoid a false positive
 		 * in static analysis.
 		 */
 		g_clear_object(&manager);
@@ -348,7 +348,7 @@ test_purple_notification_manager_read_pr
 	                 &unread_count_called);
 
 	/* Create the notification and add a reference to it before we give our
-	 * original refernce to the manager.
+	 * original reference to the manager.
 	 */
 	notification = purple_notification_new(PURPLE_NOTIFICATION_TYPE_GENERIC,
 	                                       NULL,
diff --git a/libpurple/tests/test_util.c b/libpurple/tests/test_util.c
--- a/libpurple/tests/test_util.c
+++ b/libpurple/tests/test_util.c
@@ -207,7 +207,7 @@ test_util_strdup_withhtml(void) {
 }
 
 /******************************************************************************
- * MANE
+ * MAIN
  *****************************************************************************/
 gint
 main(gint argc, gchar **argv) {
diff --git a/pidgin/pidginaccountsdisabledmenu.c b/pidgin/pidginaccountsdisabledmenu.c
--- a/pidgin/pidginaccountsdisabledmenu.c
+++ b/pidgin/pidginaccountsdisabledmenu.c
@@ -52,7 +52,7 @@ pidgin_accounts_disabled_menu_refresh(Pi
 	g_list_free(menu->accounts);
 	menu->accounts = purple_account_manager_get_disabled(manager);
 
-	/* Similar to the aboved note about removed items, if every account is
+	/* Similar to the above note about removed items, if every account is
 	 * enabled, we add an item saying "no disabled accounts".
 	 */
 	added = MAX(1, g_list_length(menu->accounts));

diff --git a/libpurple/tests/test_notification.c b/libpurple/tests/test_notification.c
--- a/libpurple/tests/test_notification.c
+++ b/libpurple/tests/test_notification.c
@@ -26,7 +26,7 @@
  * Helpers
  *****************************************************************************/
 static void
-test_purple_notification_destory_data_callback(gpointer data) {
+test_purple_notification_destroy_data_callback(gpointer data) {
 	gboolean *called = data;
 
 	*called = TRUE;
@@ -70,7 +70,7 @@ test_purple_notification_new(void) {
 	created_timestamp = purple_notification_get_created_timestamp(notification);
 	g_assert_nonnull(created_timestamp);
 
 	/* Unref it to destory it. */
 	g_clear_object(&notification);
 
 	/* Clean up the account. */
@@ -78,7 +78,7 @@ test_purple_notification_new(void) {
 }
 
 static void
-test_purple_notification_destory_data_func(void) {
+test_purple_notification_destroy_data_func(void) {
 	PurpleNotification *notification = NULL;
 	gboolean called = FALSE;
 
@@ -86,12 +86,12 @@ test_purple_notification_destory_data_fu
 	notification = purple_notification_new(PURPLE_NOTIFICATION_TYPE_GENERIC,
 	                                       NULL,
 	                                       &called,
-	                                       test_purple_notification_destory_data_callback);
+	                                       test_purple_notification_destroy_data_callback);
 
 	/* Sanity check. */
 	g_assert_true(PURPLE_IS_NOTIFICATION(notification));
 
 	/* Unref it to force the destory callback to be called. */
 	g_clear_object(&notification);
 
 	/* Make sure the callback was called. */
@@ -156,8 +156,8 @@ main(gint argc, gchar *argv[]) {
 
 	g_test_add_func("/notification/new",
 	                test_purple_notification_new);
-	g_test_add_func("/notification/destory-data-func",
-	                test_purple_notification_destory_data_func);
+	g_test_add_func("/notification/destroy-data-func",
+	                test_purple_notification_destroy_data_func);
 	g_test_add_func("/notification/properties",
 	                test_purple_notification_properties);
 
@@ -70,7 +70,7 @@ test_purple_notification_new(void) {
 	g_assert_nonnull(created_timestamp);
 
-	/* Unref it to destory it. */
+	/* Unref it to destroy it. */
 	g_clear_object(&notification);
 
@@ -86,12 +86,12 @@ test_purple_notification_destory_data_fu
 	g_assert_true(PURPLE_IS_NOTIFICATION(notification));
 
-	/* Unref it to force the destory callback to be called. */
+	/* Unref it to force the destroy callback to be called. */
 	g_clear_object(&notification);
 